@@ -1,3 +1,4 @@
+import hashlib
 import hmac
 import json
 import time
@@ -38,7 +39,6 @@ class VipClient:
         """
         return self.api_invoke(method='getByGoodsIdsV2', **kwargs)
 
-
     def api_invoke(self, method='', **kwargs):
         """
         Api 调用通用方法
@@ -49,11 +49,6 @@ class VipClient:
             req_str += key + str(params[key])
         data = json.dumps(kwargs, ensure_ascii=False)
         req_str += data
-        m = hmac.new(self.__appSecret.encode(), req_str.encode())
+        m = hmac.new(self.__appSecret.encode(), req_str.encode(), hashlib.md5)
         params['sign'] = m.hexdigest().upper()
         return requests.post(f'{self.__host}?{urlencode(params)}', headers=self.__default_headers, data=data.encode('utf-8'), timeout=self.__timeout)
-
-
-
-
-
